@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/GL/glx/single2.c,v 1.8 2004/02/10 22:54:15 alanh Exp $ */
 /*
 ** License Applicability. Except to the extent portions of this file are
 ** made subject to an alternative license as permitted in the SGI Free
@@ -270,12 +269,12 @@ char *__glXcombine_strings(const char *cext_string, const char *sext_string)
    if (clen > slen) {
 	combo_string = (char *) xalloc(slen + 2);
 	s1 = (char *) xalloc(slen + 2);
-	strcpy(s1, sext_string);
+	if (s1) strcpy(s1, sext_string);
 	s2 = cext_string;
    } else {
 	combo_string = (char *) xalloc(clen + 2);
 	s1 = (char *) xalloc(clen + 2);
-	strcpy(s1, cext_string);
+	if (s1) strcpy(s1, cext_string);
 	s2 = sext_string;
    }
    if (!combo_string || !s1) {
