@@ -30,7 +30,6 @@ or other dealings in this Software without prior written authorization
 of the copyright holder.
 
 ************************************************************/
-/* $XdotOrg: xserver/xorg/Xext/xevie.c,v 1.11 2005/10/06 17:55:54 alanc Exp $ */
 
 #define NEED_REPLIES
 #define NEED_EVENTS
@@ -59,7 +58,9 @@ of the copyright holder.
 
 #define NoSuchEvent 0x80000000
 
+#ifdef XKB
 extern Bool noXkbExtension;
+#endif
 extern int    xeviegrabState;
 
 static int		ProcDispatch (register ClientPtr client), SProcDispatch (register ClientPtr client);
@@ -104,7 +105,7 @@ typedef struct {
 } xevieKeycQueueRec, *xevieKeycQueuePtr;
 
 #define KEYC_QUEUE_SIZE	    100
-xevieKeycQueueRec keycq[KEYC_QUEUE_SIZE] = {0, NULL};
+xevieKeycQueueRec keycq[KEYC_QUEUE_SIZE] = {{0, NULL}};
 static int keycqHead = 0, keycqTail = 0;
 
 static int              ProcDispatch (ClientPtr), SProcDispatch (ClientPtr);
@@ -165,7 +166,6 @@ void ResetProc (ExtensionEntry *extEntry)
 static 
 int ProcQueryVersion (register ClientPtr client)
 {
-    REQUEST (xXevieQueryVersionReq);
     xXevieQueryVersionReply rep;
 
     REQUEST_SIZE_MATCH (xXevieQueryVersionReq);
@@ -181,7 +181,6 @@ int ProcQueryVersion (register ClientPtr client)
 static
 int ProcStart (register ClientPtr client)
 {
-    REQUEST (xXevieStartReq);
     xXevieStartReply rep;
 
     REQUEST_SIZE_MATCH (xXevieStartReq);
@@ -203,12 +202,14 @@ int ProcStart (register ClientPtr client)
            return BadAlloc;
     } else
         return BadAccess;
+#ifdef XKB
     if (!noXkbExtension) {
 	if (!XevieStart()) {
             DeleteCallback(&ClientStateCallback,XevieClientStateCallback,NULL);
             return BadAlloc;
         }
     }
+#endif
     
     xevieModifiersOn = FALSE;
 
@@ -257,19 +258,23 @@ int ProcSend (register ClientPtr client)
 	case KeyPress:
         case KeyRelease:
 	  xevieKBEventSent = 1;
-          if(noXkbExtension)
-            CoreProcessKeyboardEvent (xE, xeviekb, 1);
-	  else 
+#ifdef XKB
+          if(!noXkbExtension)
 	    doSendEvent(xE, inputInfo.keyboard);
+	  else 
+#endif
+            CoreProcessKeyboardEvent (xE, xeviekb, 1);
 	  break;
 	case ButtonPress:
 	case ButtonRelease:
 	case MotionNotify:
 	  xevieEventSent = 1;
-	  if(noXkbExtension)
-	    CoreProcessPointerEvent(xE, xeviemouse, 1); 
-	  else
+#ifdef XKB
+	  if(!noXkbExtension)
 	    doSendEvent(xE, inputInfo.pointer);
+	  else
+#endif
+	    CoreProcessPointerEvent(xE, xeviemouse, 1); 
 	  break; 
 	default:
 	  break;
@@ -466,6 +471,7 @@ XevieKbdProcessInputProc(xEvent *xE, DeviceIntPtr dev, int count)
         xE->u.keyButtonPointer.state = keyc->state | inputInfo.pointer->button->state;
         /* fix bug: sequence lost in Xlib */
         xE->u.u.sequenceNumber = clients[xevieClientIndex]->sequence;
+#ifdef XKB
 	/* fix for bug5092586 */
 	if(!noXkbExtension) {
           switch(xE->u.u.type) {
@@ -473,6 +479,7 @@ XevieKbdProcessInputProc(xEvent *xE, DeviceIntPtr dev, int count)
 	    case KeyRelease: *kptr &= ~bit; break;
 	  }
 	}
+#endif
 	keycq[keycqHead].time = xE->u.keyButtonPointer.time;
 	memcpy(keycq[keycqHead].keyc, keyc, sizeof(KeyClassRec) - sizeof(KeyClassPtr));
 	memcpy(keycq[keycqHead].keyc->xkbInfo, keyc->xkbInfo, sizeof(XkbSrvInfoRec));
@@ -527,6 +534,7 @@ XevieEnd(int clientIndex)
 {
     if (!clientIndex || clientIndex == xevieClientIndex) {
 
+#ifdef XKB
        if(!noXkbExtension) {
 
 	   XevieRemove(inputInfo.keyboard,NULL);
@@ -542,6 +550,7 @@ XevieEnd(int clientIndex)
            inputInfo.pointer->public.realInputProc = CoreProcessPointerEvent;
            XkbSetExtension(inputInfo.pointer,ProcessPointerEvent);
        }
+#endif
 
        xevieFlag = 0;
        xevieClientIndex = 0;
