@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/dix/swaprep.c,v 3.7 2001/12/14 19:59:33 dawes Exp $ */
 /************************************************************
 
 Copyright 1987, 1998  The Open Group
@@ -46,7 +45,6 @@ SOFTWARE.
 
 ********************************************************/
 
-/* $Xorg: swaprep.c,v 1.4 2001/02/09 02:04:41 xorgcvs Exp $ */
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
@@ -65,11 +63,9 @@ SOFTWARE.
 
 static void SwapFontInfo(xQueryFontReply *pr);
 
-#ifndef LBX
 static void SwapCharInfo(xCharInfo *pInfo);
 
 static void SwapFont(xQueryFontReply *pr, Bool hasGlyphs);
-#endif
 
 /**
  * Thanks to Jack Palevich for testing and subsequently rewriting all this
@@ -391,10 +387,7 @@ SQueryKeymapReply(ClientPtr pClient, int size, xQueryKeymapReply *pRep)
     (void)WriteToClient(pClient, size, (char *) pRep);
 }
 
-#ifndef LBX
-static
-#endif
-void
+static void
 SwapCharInfo(xCharInfo *pInfo)
 {
     register char n;
@@ -423,10 +416,7 @@ SwapFontInfo(xQueryFontReply *pr)
     swapl(&pr->nCharInfos, n);
 }
 
-#ifndef LBX
-static
-#endif
-void
+static void
 SwapFont(xQueryFontReply *pr, Bool hasGlyphs)
 {
     unsigned	i;
