@@ -116,31 +116,11 @@ extern Bool noXkbExtension;
     xf86UnblockSIGIO(__sigstate); \
 }
 
-#ifdef XTESTEXT1
-
-#define	XTestSERVER_SIDE
-#include <X11/extensions/xtestext1.h>
-extern short xtest_mousex;
-extern short xtest_mousey;
-extern int   on_steal_input;          
-extern Bool  XTestStealKeyData();
-extern void  XTestStealMotionData();
-#define ENQUEUE(ev, code, direction, dev_type) \
-  (ev)->u.u.detail = (code); \
-  (ev)->u.u.type   = (direction); \
-  if (!on_steal_input ||  \
-      XTestStealKeyData((ev)->u.u.detail, (ev)->u.u.type, dev_type, \
-			xtest_mousex, xtest_mousey)) \
-  EqEnqueue((ev))
-#else /* ! XTESTEXT1 */
-
 #define ENQUEUE(ev, code, direction, dev_type) \
   (ev)->u.u.detail = (code); \
   (ev)->u.u.type   = (direction); \
   EqEnqueue((ev))
 
-#endif
-
 /*
  * The first of many hacks to get VT switching to work under
  * Solaris 2.1 for x86. The basic problem is that Solaris is supposed
@@ -1275,12 +1255,8 @@ xf86InterceptSigIll(void (*sigillhandler)(void))
     xf86SigIllHandler = sigillhandler;
 }
 
-#ifdef HAVE_EXECINFO_H
-#define HAVE_BACKTRACE
-#include <execinfo.h>
-#endif
-
 #ifdef HAVE_BACKTRACE
+#include <execinfo.h>
 
 static __inline__ void xorg_backtrace(void)
 {
@@ -1762,49 +1738,6 @@ xf86EnableVTSwitch(Bool new)
     return old;
 }
 
-#ifdef XTESTEXT1
-
-void
-XTestGetPointerPos(short *fmousex, short *fmousey)
-{
-  int x,y;
-
-  miPointerPosition(&x, &y);
-  *fmousex = x;
-  *fmousey = y;
-}
-
-
-
-void
-XTestJumpPointer(int jx, int jy, int dev_type)
-{
-  miPointerAbsoluteCursor(jx, jy, GetTimeInMillis() );
-}
-
-void
-XTestGenerateEvent(int dev_type, int keycode, int keystate, int mousex,
-		   int mousey)
-{
-  xEvent tevent;
-  
-  tevent.u.u.type = (dev_type == XE_POINTER) ?
-    (keystate == XTestKEY_UP) ? ButtonRelease : ButtonPress :
-      (keystate == XTestKEY_UP) ? KeyRelease : KeyPress;
-  tevent.u.u.detail = keycode;
-  tevent.u.keyButtonPointer.rootX = mousex;
-  tevent.u.keyButtonPointer.rootY = mousey;
-  tevent.u.keyButtonPointer.time = xf86Info.lastEventTime = GetTimeInMillis();
-#ifdef XINPUT
-  xf86eqEnqueue(&tevent);
-#else
-  mieqEnqueue(&tevent);
-#endif
-  xf86Info.inputPending = TRUE;               /* virtual event */
-}
-
-#endif /* XTESTEXT1 */
-
 void
 xf86ReloadInputDevs(int sig)
 {
