@@ -1,5 +1,5 @@
 /*
- * $Id: damage.c,v 1.17 2005/07/03 07:02:01 daniels Exp $
+ * $Id$
  *
  * Copyright © 2003 Keith Packard
  *
@@ -26,6 +26,8 @@
 #include <dix-config.h>
 #endif
 
+#include <stdlib.h>
+
 #include    <X11/X.h>
 #include    "scrnintstr.h"
 #include    "windowstr.h"
@@ -1635,9 +1637,6 @@ GCOps damageGCOps = {
     damagePolyText16, damageImageText8,
     damageImageText16, damageImageGlyphBlt,
     damagePolyGlyphBlt, damagePushPixels,
-#ifdef NEED_LINEHELPER
-    NULL,
-#endif
     {NULL}		/* devPrivate */
 };
 
@@ -1958,7 +1957,7 @@ DamageRegion (DamagePtr		    pDamage)
     return &pDamage->damage;
 }
 
-void
+_X_EXPORT void
 DamageDamageRegion (DrawablePtr	pDrawable,
 		    RegionPtr	pRegion)
 {
